/*  BOING version 1.00           Copyright (C) 1992 by Jim Robeson
 *                                                     11/25/92
 *  Function:
 *    Delete the current directory and all the files inside;
 *    but, do NOTHING if any Read-Only, Hidden, System or
 *    sub-Directory files are found.  Switches to the ROOT
 *    directory of the current drive when finished.
 *
 *  Other uses:
 *    None.
 *
 *  Execution:
 *    Run from command line
 *      BOING
 *      answer Y for yes twice and the deed will be done.
 *
 *  Compiled with:
 *    Borland's Turbo C 2.0.
 *    tcc boing
 *
 *  Disclaimer:
 *    This program is contributed to the Public Domain.  It can be
 *    freely used, modified and/or distributed by anyone. The only
 *    thing I ask is that you remember that I am not responsible
 *    for anything that might go wrong through the use of this
 *    program.  I have tested the program enough for my own use.
 *    I also realize that bugs can appear in most every program.
 *    Therefore, YOU USE THIS PROGRAM AT YOUR OWN RISK.
 *
 *  To-do:
 *    > nothing
 *
 *  Enjoy,
 *  Jim Robeson
 *  The Cricket BBS, Pacific Grove CA,  408-373-3773
 */

#include <dir.h>
#include <dos.h>
#include <stdio.h>
#include <string.h>

/* ========================================= */
/* ===  MAIN                             === */
/* ========================================= */
main()
{
  char reply;
  int done;
  char curcwd[MAXPATH];
  char curdrv[5];
  struct ffblk ffblk; /* structure for FINDFIRST & FINDNEXT    */
                       /* char ff_reserved[21] reserved by DOS */
                       /* char ff_attrib       attribute found */
                       /* int  ff_ftime        file time       */
                       /* int  ff_fdate        file date       */
                       /* long ff_fsize        file size       */
                       /* char ff_name[13]     found file name */

                      /* attrib defines are thus:              */
                       /*           = 0x00  for "normal" files */
                       /* FA_RDONLY = 0x01  for Read only file */
                       /* FA_HIDDEN = 0x02  for Hidden file    */
                       /* FA_SYSTEM = 0x04  for System file    */
                       /* FA_LABEL  = 0x08  for Volume label   */
                       /* FA_DIREC  = 0x10  for Directory      */
                       /* FA_ARCH   = 0x20  for Archive        */

                      /* attrib gives out this:                */
                       /*        = BL Arc RdO Hid Sys Dir      */
                       /* 0      = 0  32  33                   */
                       /* RDONLY = 0  32  33                   */
                       /* HIDDEN = 0  32  33  34               */
                       /* SYSTEM = 0  32  33      36           */
                       /* DIREC  = 0  32  33          16 &not. */
                       /* ARCH   = 0  32  33                   */

/* ------------------------------------------------------- */
/* FIND CURRENT DIRECTORY -------------------------------- */
/* ------------------------------------------------------- */
  getcwd(curcwd,MAXPATH);            /* curcwd = 'C:\TC'   */

/* ------------------------------------------------------- */
/* QUERY THE USER TO MAKE SURE ABOUT THIS !! ------------- */
/* ------------------------------------------------------- */
  printf("Deleting totally DIRectory %s\n",curcwd);
  printf("  Are you sure ? ");
  reply = getche();
  if (reply=='y' || reply =='Y') printf("\n");
    else { printf("\nBOING canceled.\n");
           exit(1); }
  printf("  Double sure ?? ");
  reply = getche();
  if (reply=='y' || reply =='Y') printf("\n");
    else { printf("\nBOING canceled.\n");
           exit(1); }

/* ------------------------------------------------------- */
/* CHECK FOR SPECIAL CASE FILES FIRST -------------------- */
/* ------------------------------------------------------- */
  reply = 'Y';
  done = findfirst("*.*",&ffblk,FA_RDONLY);
  while (!done)
    { if (ffblk.ff_attrib & FA_RDONLY)
      { reply = 'N'; printf("--> read-only file found\n"); }
      done = findnext(&ffblk); }

  done = findfirst("*.*",&ffblk,FA_HIDDEN);
  while (!done)
    { if (ffblk.ff_attrib & FA_HIDDEN)
      { reply = 'N'; printf("--> hidden file found\n"); }
      done = findnext(&ffblk); }

  done = findfirst("*.*",&ffblk,FA_SYSTEM);
  while (!done)
    { if (ffblk.ff_attrib & FA_SYSTEM)
      { reply = 'N'; printf("--> system file found\n"); }
      done = findnext(&ffblk); }

  done = findfirst("*.*",&ffblk,FA_DIREC);
  while (!done)
    { if (ffblk.ff_attrib & FA_DIREC && ffblk.ff_name[0] != '.')
      { reply = 'N'; printf("--> sub-directory found\n"); }
      done = findnext(&ffblk); }

  if (reply == 'N')
    { printf("BOING ABORTED, non-deletable files found.");
      exit(1); }

/* ------------------------------------------------------- */
/* WE'RE GOING AHEAD, TELL THE USER ---------------------- */
/* ------------------------------------------------------- */
  printf("    removing %s\\*.*\n",curcwd);

/* ------------------------------------------------------- */
/* ERASE ALL FILES FOUND INSIDE PREVIOUS CURRENT DIRECTORY */
/* ------------------------------------------------------- */
  done = findfirst("*.*",&ffblk,0);
  while (!done) {
  /*  printf("    removing %s\n",ffblk.ff_name); */
      unlink(ffblk.ff_name);
      done = findnext(&ffblk);
    }

/* ------------------------------------------------------- */
/* CHANGE TO ROOT DIR OF CURRENT DRIVE  ------------------ */
/* ------------------------------------------------------- */
  strcpy(curdrv,"X:\\");            /* curdrv = 'X:\'     */
  curdrv[0] = 'A' + getdisk();      /* curdrv = 'C:\'     */
  chdir(curdrv);

/* ------------------------------------------------------- */
/* REMOVE PREVIOUS CURRENT DIRECTORY --------------------- */
/* ------------------------------------------------------- */
  rmdir(curcwd);
  printf("BOING finished, %s is no more.\n",curcwd);
  exit(0);

}  /* ------------- end of main ------------------------------- */

/*------------- End of BOING.C ---------------------------------------*/
